==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'affichage_documents_en_cases' => 'Mostrar en cajas',
	'affichage_documents_en_grand' => 'Pantalla grande',
	'affichage_documents_en_liste_compacte' => 'Visualización compacta de la lista',
	'aucun_audio' => 'Ninguna pista de sonido',
	'aucun_document' => 'Ningún documento',
	'aucun_file' => 'Ningún documento',
	'aucun_image' => 'Ninguna imagen',
	'aucun_video' => 'Ninguna secuencia',
	'aucune_utilisation' => 'Este documento no se utiliza',
	'aucune_vignette' => 'Ninguna miniatura',

	// B
	'bouton_ajouter_document' => 'Añadir un documento',
	'bouton_ajouter_image' => 'Añadir una imagen',
	'bouton_ajouter_image_document' => 'Añadir una imagen o un documento',
	'bouton_attacher_document' => 'Adjuntar',
	'bouton_copier_local' => 'Copiar en el sitio',
	'bouton_download_depuis' => 'desde:',
	'bouton_download_local' => 'Mi ordenador',
	'bouton_download_par_ftp' => 'el servidor',
	'bouton_download_par_mediatheque' => 'la mediateca',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Desprender',
	'bouton_enlever_supprimer_document' => 'Eliminar',
	'bouton_enlever_supprimer_document_confirmation' => '¿Está seguro de querer eliminar el documento?',
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Examinar...',
	'bouton_refresh_document' => 'Actualizar el documento',
	'bouton_remplacer_document' => 'Sustituir este documento',
	'bouton_remplacer_image' => 'Sustituir esta imagen',
	'bouton_remplacer_image_document' => 'Sustituir por una imagen o documento',
	'bouton_supprimer' => 'Eliminar',
	'bouton_supprimer_tous_orphelins' => 'Eliminar todos los documentos no utilizados',
	'bouton_supprimer_tous_orphelins_confirmation' => '¿Está seguro de querer eliminar @nb@ documentos no utilizados?',
	'bouton_upload' => 'Subir',

	// D
	'des_audios' => '@nb@ pistas de sonido',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imágenes',
	'des_utilisations' => '@nb@ usos',
	'des_videos' => '@nb@ secuencias',
	'descriptif' => 'Descripción',
	'details_document' => 'Detalles',
	'details_document_afficher_masquer' => 'Mostrar / ocultar los detalles del documento',
	'document_attache_succes' => 'El documento ha sido añadido',
	'document_copie_locale_succes' => '	El archivo ha sido copiado en el sitio',
	'document_installe_succes' => 'El archivo ha sido cargado',
	'document_vu' => 'Introducido en el texto',
	'documents' => 'Mediateca',
	'documents_brises' => 'Rotos',
	'documents_distants' => 'Remoto',
	'documents_locaux' => 'Local',
	'documents_non_publies' => 'No publicados',
	'documents_orphelins' => 'No utilizados',
	'documents_publies' => 'Publicado',
	'documents_tous' => 'Todo',
	'double_clic_inserer_doc' => 'Haga doble clic para insertar este atajo en el texto',

	// E
	'entree_dimensions' => 'Dimensiones:',
	'entree_titre_document' => 'Título del documento:',
	'entree_titre_image' => 'Título de la imagen:',
	'erreur_aucun_document' => 'Este documento no existe en la mediateca',
	'erreur_aucun_fichier' => 'No se encontraron archivos',
	'erreur_autorisation' => 'Error de autorización.',
	'erreur_chemin_distant' => 'No se encontró el archivo remoto @nom@',
	'erreur_chemin_ftp' => 'El archivo indicado no se encuentra en el servidor',
	'erreur_copie_fichier' => 'No se puede copiar el archivo @nom@',
	'erreur_deplacement_impossible' => 'No se puede mover.',
	'erreur_dossier_tmp_manquant' => 'Falta una carpeta temporal para poder subir los archivos',
	'erreur_ecriture_fichier' => 'Error durante la escritura del archivo en disco',
	'erreur_format_fichier_image' => 'El formato de @nom@ no es adecuado para una imagen',
	'erreur_indiquez_un_fichier' => 'Especifique un archivo!',
	'erreur_insertion_document_base' => 'Imposible guardar el documento @fichier@ en la base de datos',
	'erreur_objet_absent' => 'Informaciones recibidas incompletas.',
	'erreur_suppression_vignette' => 'Error al eliminar la miniatura',
	'erreur_upload_type_interdit' => 'Descarga de archivos de tipo @nom@ no permitida',
	'erreur_upload_vignette' => 'Error al cargar miniatura @nom@',
	'erreurs' => '@nb@ errores',
	'erreurs_voir' => 'Ver los @nb@ errores',

	// F
	'fichier_distant' => 'Archivo remoto',
	'fichier_manquant' => 'Falta el archivo',
	'fichier_modifie' => 'El archivo ha sido modificado. Haga clic en Guardar.',
	'format_date_incorrect' => 'La fecha o la hora son incorrectas',

	// I
	'icone_creer_document' => 'Añadir documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rotación de 180°',
	'image_tourner_droite' => 'Rotación de 90° a la derecha',
	'image_tourner_gauche' => 'Rotación de 90° a la izquierda',
	'info_alt' => 'Descripción del contenido de la imagen cuando no es visible, además del título.',
	'info_dimensions_image' => 'Tamaño',
	'info_doc_max_poids' => 'Los documentos deben tener un tamaño inferior a @maxi@ (este archivo es de @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento no está disponible',
	'info_documents' => 'Documentos',
	'info_duree' => 'Duración',
	'info_gauche_numero_document' => 'DOCUMENTO NÚMERO',
	'info_hauteur' => 'Alto',
	'info_heure' => 'Hora',
	'info_illustrations' => 'Ilustraciones',
	'info_image_max_poids' => 'Las imágenes deben obligatoriamente pesar menos de @maxi@ (este archivo pesa @actuel@).',
	'info_image_max_taille' => 'Las imágenes deben obligatoriamente pesar menos de @maxi@ (este archivo pesa @actuel@).',
	'info_image_min_taille' => 'Las imágenes deben ser como mínimo de @mini@ (ahora es de @actual@).',
	'info_inclusion_directe' => 'Inclusión directa:',
	'info_inclusion_vignette' => 'Inclusión de la miniatura:',
	'info_installer_tous_documents' => 'Instalar todos los documentos',
	'info_largeur' => 'Ancho',
	'info_logo_max_taille' => 'Los logos deben obligatoriamente tener un tamaño menor de @maxi@ (el archivo es de @actuel@).',
	'info_mode' => 'Modo',
	'info_modifier_document' => 'Editar el documento',
	'info_portfolio' => 'Portafolio',
	'info_referencer_doc_distant' => 'Referenciar un documento en Internet:',
	'info_resolution_image' => 'Resolución',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Sin miniatura',
	'info_statut_document' => 'Este documento es:',
	'info_taille' => 'Tamaño',
	'info_telecharger' => 'Subir desde tu equipo:',
	'info_utilisation' => 'Uso(s)',
	'infos' => 'Información técnica',
	'inserer_raccourci' => 'Inserte este atajo en el texto',
	'item_autoriser_selectionner_date_en_ligne' => 'Permitir la modificación de la fecha de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La fecha de los documentos corresponde al momento en que fueron subidos al sitio web',

	// L
	'label_activer_document_objets' => 'Activar el poder subir archivos para los contenidos:',
	'label_alt' => 'Texto alternativo (alt)',
	'label_apercu' => 'Vista previa',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Archivo',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginar por:',
	'label_parents' => 'Este documento está relacionado con',
	'label_refdoc_joindre' => 'Documento número',
	'label_titre_mimetype' => 'Tipo de archivo',
	'lien_tout_desordonner' => 'Reinicializar le órden',
	'lien_tout_desordonner_verif' => 'El órden definido para esta lsita va a ser reinicializado. 
¿Seguro?',
	'lien_tout_enlever' => 'Quitar todo',
	'lien_tout_enlever_verif' => '¿Quiere separar todos los documentos?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Pistas de sonido',
	'media_file' => 'Otro',
	'media_image' => 'Imágenes',
	'media_video' => 'Secuencias',
	'miniature_automatique_active' => 'SPIP genera automáticamente una miniatura de la imagen',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos se han añadido correctamente',
	'nb_documents_installe_succes' => '@nb@ los archivos cargados con éxito',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',
	'ordonner_ce_document' => 'Ordenar este documento',

	// P
	'par_date' => 'Fecha',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Anchura',
	'par_taille' => 'Tamaño',
	'par_titre' => 'Titulo',

	// T
	'texte_documents_joints' => 'Puede activar la interfaz para añadir documentos (archivos de ofimática, imágenes, multimedia, etc.) a los artículos, las secciones y otros. Estos archivos pueden ser incluirse después en el texto, o mostrarse por separado.',
	'texte_documents_joints_2' => 'Este ajuste no impide subir imágenes a los artículos ni la inserción de documentos en los textos de contenido.',
	'titre_documents_joints' => 'Documentos adjuntos',
	'titre_page_documents_edit' => 'Modificar el documento: @titre@',
	'tous_les_medias' => 'Todos los medios',
	'tout_dossier_upload' => 'Toda la carpeta @upload@',
	'tout_voir' => 'Ver todo',

	// U
	'un_audio' => '1 pista de sonido',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagen',
	'un_video' => '1 secuencia',
	'une_utilisation' => '1 utilización',
	'upload_fichier_zip' => 'Archivo ZIP',
	'upload_fichier_zip_texte' => 'El archivo que propone instalar es un archivo Zip.',
	'upload_fichier_zip_texte2' => 'Este archivo puede ser:',
	'upload_info_mode_document' => 'Enviar a el portafolio',
	'upload_info_mode_image' => 'Eliminar del portafolio',
	'upload_limit' => 'Este archivo es demasiado grande para el servidor; el tamaño máximo autorizado en <i>upload</i> es de @max@.',
	'upload_zip_conserver' => 'Conservar el archivo tras la extracción',
	'upload_zip_decompacter' => 'descomprimido y cada elemento que contiene instalado en el sitio. Los archivos que se van a instalar en el sitio son:',
	'upload_zip_mode_document' => 'Depositar todas las imágenes en el portafolio',
	'upload_zip_telquel' => 'instalado tal cual, como archivo Zip comprimido;',
	'upload_zip_titrer' => 'Titular según el nombre de los archivos',

	// V
	'verifier_documents_brises' => 'Verificar los archivos que faltan',
	'verifier_documents_inutilises' => 'Vérificar los enlaces de los documentos',
	'vignette_supprimee' => 'La miniatura se ha eliminado'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_es.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// A
	'affichage_documents_en_cases' => 'Mostrar en cajas',
	'affichage_documents_en_grand' => 'Pantalla grande',
	'affichage_documents_en_liste_compacte' => 'Visualización compacta de la lista',
	'aucun_audio' => 'Ninguna pista de sonido',
	'aucun_document' => 'Ningún documento',
	'aucun_file' => 'Ningún documento',
	'aucun_image' => 'Ninguna imagen',
	'aucun_video' => 'Ninguna secuencia',
	'aucune_utilisation' => 'Este documento no se utiliza',
	'aucune_vignette' => 'Ninguna miniatura',

	// B
	'bouton_ajouter_document' => 'Añadir un documento',
	'bouton_ajouter_image' => 'Añadir una imagen',
	'bouton_ajouter_image_document' => 'Añadir una imagen o un documento',
	'bouton_attacher_document' => 'Adjuntar',
	'bouton_copier_local' => 'Copiar en el sitio',
	'bouton_download_depuis' => 'desde:',
	'bouton_download_local' => 'Mi ordenador',
	'bouton_download_par_ftp' => 'el servidor',
	'bouton_download_par_mediatheque' => 'la mediateca',
	'bouton_download_sur_le_web' => 'Internet',
	'bouton_enlever_document' => 'Desprender',
	'bouton_enlever_supprimer_document' => 'Eliminar',
	'bouton_enlever_supprimer_document_confirmation' => '¿Está seguro de querer eliminar el documento?',
	'bouton_modifier_document' => 'Modificar',
	'bouton_parcourir' => 'Examinar...',
	'bouton_refresh_document' => 'Actualizar el documento',
	'bouton_remplacer_document' => 'Sustituir este documento',
	'bouton_remplacer_image' => 'Sustituir esta imagen',
	'bouton_remplacer_image_document' => 'Sustituir por una imagen o documento',
	'bouton_supprimer' => 'Eliminar',
	'bouton_supprimer_tous_orphelins' => 'Eliminar todos los documentos no utilizados',
	'bouton_supprimer_tous_orphelins_confirmation' => '¿Está seguro de querer eliminar @nb@ documentos no utilizados?',
	'bouton_upload' => 'Subir',

	// D
	'des_audios' => '@nb@ pistas de sonido',
	'des_documents' => '@nb@ documentos',
	'des_files' => '@nb@ documentos',
	'des_images' => '@nb@ imágenes',
	'des_utilisations' => '@nb@ usos',
	'des_videos' => '@nb@ secuencias',
	'descriptif' => 'Descripción', # MODIF
	'details_document' => 'Detalles',
	'details_document_afficher_masquer' => 'Mostrar / ocultar los detalles del documento',
	'document_attache_succes' => 'El documento ha sido añadido',
	'document_copie_locale_succes' => '	El archivo ha sido copiado en el sitio',
	'document_installe_succes' => 'El archivo ha sido cargado',
	'document_vu' => 'Introducido en el texto',
	'documents' => 'Mediateca',
	'documents_brises' => 'Rotos',
	'documents_distants' => 'Remoto',
	'documents_locaux' => 'Local',
	'documents_non_publies' => 'No publicados',
	'documents_orphelins' => 'No utilizados',
	'documents_publies' => 'Publicado',
	'documents_tous' => 'Todo',
	'double_clic_inserer_doc' => 'Haga doble clic para insertar este atajo en el texto',

	// E
	'entree_dimensions' => 'Dimensiones:',
	'entree_titre_document' => 'Título del documento:',
	'entree_titre_image' => 'Título de la imagen:',
	'erreur_aucun_document' => 'Este documento no existe en la mediateca',
	'erreur_aucun_fichier' => 'No se encontraron archivos',
	'erreur_autorisation' => 'Error de autorización.',
	'erreur_chemin_distant' => 'No se encontró el archivo remoto @nom@',
	'erreur_chemin_ftp' => 'El archivo indicado no se encuentra en el servidor',
	'erreur_copie_fichier' => 'No se puede copiar el archivo @nom@',
	'erreur_deplacement_impossible' => 'No se puede mover.',
	'erreur_dossier_tmp_manquant' => 'Falta una carpeta temporal para poder subir los archivos',
	'erreur_ecriture_fichier' => 'Error durante la escritura del archivo en disco',
	'erreur_format_fichier_image' => 'El formato de @nom@ no es adecuado para una imagen',
	'erreur_indiquez_un_fichier' => 'Especifique un archivo!',
	'erreur_insertion_document_base' => 'Imposible guardar el documento @fichier@ en la base de datos',
	'erreur_objet_absent' => 'Informaciones recibidas incompletas.',
	'erreur_suppression_vignette' => 'Error al eliminar la miniatura',
	'erreur_upload_type_interdit' => 'Descarga de archivos de tipo @nom@ no permitida',
	'erreur_upload_vignette' => 'Error al cargar miniatura @nom@',
	'erreurs' => '@nb@ errores',
	'erreurs_voir' => 'Ver los @nb@ errores',

	// F
	'fichier_distant' => 'Archivo remoto',
	'fichier_manquant' => 'Falta el archivo',
	'fichier_modifie' => 'El archivo ha sido modificado. Haga clic en Guardar.',
	'format_date_incorrect' => 'La fecha o la hora son incorrectas',

	// I
	'icone_creer_document' => 'Añadir documento',
	'id' => 'ID',
	'image_tourner_180' => 'Rotación de 180°',
	'image_tourner_droite' => 'Rotación de 90° a la derecha',
	'image_tourner_gauche' => 'Rotación de 90° a la izquierda',
	'info_alt' => 'Descripción del contenido de la imagen cuando no es visible, además del título.',
	'info_dimensions_image' => 'Tamaño',
	'info_doc_max_poids' => 'Los documentos deben tener un tamaño inferior a @maxi@ (este archivo es de @actuel@).',
	'info_document' => 'Documento',
	'info_document_indisponible' => 'Este documento no está disponible',
	'info_documents' => 'Documentos',
	'info_duree' => 'Duración',
	'info_gauche_numero_document' => 'DOCUMENTO NÚMERO',
	'info_hauteur' => 'Alto',
	'info_heure' => 'Hora',
	'info_illustrations' => 'Ilustraciones',
	'info_image_max_poids' => 'Las imágenes deben obligatoriamente pesar menos de @maxi@ (este archivo pesa @actuel@).',
	'info_image_max_taille' => 'Las imágenes deben obligatoriamente pesar menos de @maxi@ (este archivo pesa @actuel@).',
	'info_image_min_taille' => 'Las imágenes deben ser como mínimo de @mini@ (ahora es de @actual@).',
	'info_inclusion_directe' => 'Inclusión directa:',
	'info_inclusion_vignette' => 'Inclusión de la miniatura:',
	'info_installer_tous_documents' => 'Instalar todos los documentos',
	'info_largeur' => 'Ancho',
	'info_logo_max_taille' => 'Los logos deben obligatoriamente tener un tamaño menor de @maxi@ (el archivo es de @actuel@).',
	'info_mode' => 'Modo',
	'info_modifier_document' => 'Editar el documento',
	'info_portfolio' => 'Portafolio',
	'info_referencer_doc_distant' => 'Referenciar un documento en Internet:',
	'info_resolution_image' => 'Resolución',
	'info_resolution_mpx' => '@resolution@ Mpx',
	'info_sans_vignette' => 'Sin miniatura',
	'info_statut_document' => 'Este documento es:',
	'info_taille' => 'Tamaño',
	'info_telecharger' => 'Subir desde tu equipo:',
	'info_utilisation' => 'Uso(s)',
	'infos' => 'Información técnica',
	'inserer_raccourci' => 'Inserte este atajo en el texto',
	'item_autoriser_selectionner_date_en_ligne' => 'Permitir la modificación de la fecha de cada documento',
	'item_non_autoriser_selectionner_date_en_ligne' => 'La fecha de los documentos corresponde al momento en que fueron subidos al sitio web',

	// L
	'label_activer_document_objets' => 'Activar el poder subir archivos para los contenidos:',
	'label_alt' => 'Texto alternativo (alt)',
	'label_apercu' => 'Vista previa',
	'label_caracteristiques' => 'Características',
	'label_credits' => 'Créditos',
	'label_fichier' => 'Archivo',
	'label_fichier_vignette' => 'Miniatura',
	'label_paginer_par' => 'Paginar por:',
	'label_parents' => 'Este documento está relacionado con',
	'label_refdoc_joindre' => 'Documento número',
	'label_titre_mimetype' => 'Tipo de archivo',
	'lien_tout_desordonner' => 'Reinicializar le órden',
	'lien_tout_desordonner_verif' => 'El órden definido para esta lsita va a ser reinicializado. 
¿Seguro?',
	'lien_tout_enlever' => 'Quitar todo',
	'lien_tout_enlever_verif' => '¿Quiere separar todos los documentos?',
	'logo' => 'Logo',

	// M
	'media_audio' => 'Pistas de sonido',
	'media_file' => 'Otro',
	'media_image' => 'Imágenes',
	'media_video' => 'Secuencias',
	'miniature_automatique_active' => 'SPIP genera automáticamente una miniatura de la imagen',

	// N
	'nb_documents_attache_succes' => '@nb@ documentos se han añadido correctamente',
	'nb_documents_installe_succes' => '@nb@ los archivos cargados con éxito',

	// O
	'objet_document' => 'Documento',
	'objet_documents' => 'Documentos',
	'ordonner_ce_document' => 'Ordenar este documento',

	// P
	'par_date' => 'Fecha',
	'par_hauteur' => 'Altura',
	'par_id' => 'ID',
	'par_largeur' => 'Anchura',
	'par_taille' => 'Tamaño',
	'par_titre' => 'Titulo',

	// T
	'texte_documents_joints' => 'Puede activar la interfaz para añadir documentos (archivos de ofimática, imágenes, multimedia, etc.) a los artículos, las secciones y otros. Estos archivos pueden ser incluirse después en el texto, o mostrarse por separado.',
	'texte_documents_joints_2' => 'Este ajuste no impide subir imágenes a los artículos ni la inserción de documentos en los textos de contenido.',
	'titre_documents_joints' => 'Documentos adjuntos',
	'titre_page_documents_edit' => 'Modificar el documento: @titre@',
	'tous_les_medias' => 'Todos los medios',
	'tout_dossier_upload' => 'Toda la carpeta @upload@',
	'tout_voir' => 'Ver todo',

	// U
	'un_audio' => '1 pista de sonido',
	'un_document' => '1 documento',
	'un_file' => '1 documento',
	'un_image' => '1 imagen',
	'un_video' => '1 secuencia',
	'une_utilisation' => '1 utilización',
	'upload_fichier_zip' => 'Archivo ZIP',
	'upload_fichier_zip_texte' => 'El archivo que propone instalar es un archivo Zip.',
	'upload_fichier_zip_texte2' => 'Este archivo puede ser:',
	'upload_info_mode_document' => 'Enviar a el portafolio',
	'upload_info_mode_image' => 'Eliminar del portafolio',
	'upload_limit' => 'Este archivo es demasiado grande para el servidor; el tamaño máximo autorizado en <i>upload</i> es de @max@.',
	'upload_zip_conserver' => 'Conservar el archivo tras la extracción',
	'upload_zip_decompacter' => 'descomprimido y cada elemento que contiene instalado en el sitio. Los archivos que se van a instalar en el sitio son:',
	'upload_zip_mode_document' => 'Depositar todas las imágenes en el portafolio',
	'upload_zip_telquel' => 'instalado tal cual, como archivo Zip comprimido;',
	'upload_zip_titrer' => 'Titular según el nombre de los archivos',

	// V
	'verifier_documents_brises' => 'Verificar los archivos que faltan',
	'verifier_documents_inutilises' => 'Vérificar los enlaces de los documentos',
	'vignette_supprimee' => 'La miniatura se ha eliminado',
];
